// An example of drweb-netcheck API usage in asynchronous mode with flow control support.
// (C) 2003-2015 Doctor Web. All rights reserved.

#include <stdlib.h>
#include <sys/stat.h>

#include <cstdint>
#include <iostream>
#include <map>

#include "drweb_netcheck_scanner.h"

using namespace nc;
using namespace dw;

static const std::vector<std::string> files = { "/bin/ls", "/bin/rm", "/bin/sh" };

int main(int argc, char* argv[])
{
    try {
        if(argc != 2) {
            std::ostringstream os;
            os << "Usage: " << argv[0] << " <socket path>";
            throw std::runtime_error(os.str());
        }

        std::string ncheck_socket_path = argv[1];
        boost::asio::io_service io;

        std::shared_ptr<netcheck_api_t> netcheck_api = netcheck_api_t::create(io);
        netcheck_api->start(ncheck_socket_path);

        scanner_t scanner(netcheck_api);
        scanner.start(files);

        io.run();
    } catch(const std::exception& ex) {
        std::cerr << ex.what() << std::endl;
        return EXIT_FAILURE;
    }
}
